<?php

namespace Btravel\Externaldatum\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Btravel\Externaldatum\Http\Requests\GebecoRequest;
use Btravel\Externaldatum\Interfaces\GebecoRepositoryInterface;
use Btravel\Externaldatum\Models\Gebeco;

/**
 * Resource controller class for gebeco.
 */
class GebecoResourceController extends BaseController
{

    /**
     * Initialize gebeco resource controller.
     *
     * @param type GebecoRepositoryInterface $gebeco
     *
     * @return null
     */
    public function __construct(GebecoRepositoryInterface $gebeco)
    {
        parent::__construct();
        $this->repository = $gebeco;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Btravel\Externaldatum\Repositories\Criteria\GebecoResourceCriteria::class);
    }

    /**
     * Display a list of gebeco.
     *
     * @return Response
     */
    public function index(GebecoRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Btravel\Externaldatum\Repositories\Presenter\GebecoPresenter::class)
                ->$function();
        }

        $gebecos = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('externaldatum::gebeco.names'))
            ->view('externaldatum::gebeco.index', true)
            ->data(compact('gebecos', 'view'))
            ->output();
    }

    /**
     * Display gebeco.
     *
     * @param Request $request
     * @param Model   $gebeco
     *
     * @return Response
     */
    public function show(GebecoRequest $request, Gebeco $gebeco)
    {

        if ($gebeco->exists) {
            $view = 'externaldatum::gebeco.show';
        } else {
            $view = 'externaldatum::gebeco.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('externaldatum::gebeco.name'))
            ->data(compact('gebeco'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new gebeco.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(GebecoRequest $request)
    {

        $gebeco = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('externaldatum::gebeco.name')) 
            ->view('externaldatum::gebeco.create', true) 
            ->data(compact('gebeco'))
            ->output();
    }

    /**
     * Create new gebeco.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(GebecoRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $gebeco                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('externaldatum::gebeco.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('externaldatum/gebeco/' . $gebeco->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/externaldatum/gebeco'))
                ->redirect();
        }

    }

    /**
     * Show gebeco for editing.
     *
     * @param Request $request
     * @param Model   $gebeco
     *
     * @return Response
     */
    public function edit(GebecoRequest $request, Gebeco $gebeco)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('externaldatum::gebeco.name'))
            ->view('externaldatum::gebeco.edit', true)
            ->data(compact('gebeco'))
            ->output();
    }

    /**
     * Update the gebeco.
     *
     * @param Request $request
     * @param Model   $gebeco
     *
     * @return Response
     */
    public function update(GebecoRequest $request, Gebeco $gebeco)
    {
        try {
            $attributes = $request->all();

            $gebeco->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('externaldatum::gebeco.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('externaldatum/gebeco/' . $gebeco->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('externaldatum/gebeco/' . $gebeco->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the gebeco.
     *
     * @param Model   $gebeco
     *
     * @return Response
     */
    public function destroy(GebecoRequest $request, Gebeco $gebeco)
    {
        try {

            $gebeco->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('externaldatum::gebeco.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('externaldatum/gebeco/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('externaldatum/gebeco/' . $gebeco->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple gebeco.
     *
     * @param Model   $gebeco
     *
     * @return Response
     */
    public function delete(GebecoRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('externaldatum::gebeco.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('externaldatum/gebeco'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/externaldatum/gebeco'))
                ->redirect();
        }

    }

    /**
     * Restore deleted gebecos.
     *
     * @param Model   $gebeco
     *
     * @return Response
     */
    public function restore(GebecoRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('externaldatum::gebeco.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/externaldatum/gebeco'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/externaldatum/gebeco/'))
                ->redirect();
        }

    }

}
