<?php

namespace Btravel\Externaldatum\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Btravel\Externaldatum\Http\Requests\XploreRequest;
use Btravel\Externaldatum\Interfaces\XploreRepositoryInterface;
use Btravel\Externaldatum\Models\Xplore;

/**
 * Resource controller class for xplore.
 */
class XploreResourceController extends BaseController
{

    /**
     * Initialize xplore resource controller.
     *
     * @param type XploreRepositoryInterface $xplore
     *
     * @return null
     */
    public function __construct(XploreRepositoryInterface $xplore)
    {
        parent::__construct();
        $this->repository = $xplore;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Btravel\Externaldatum\Repositories\Criteria\XploreResourceCriteria::class);
    }

    /**
     * Display a list of xplore.
     *
     * @return Response
     */
    public function index(XploreRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Btravel\Externaldatum\Repositories\Presenter\XplorePresenter::class)
                ->$function();
        }

        $xplores = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('externaldatum::xplore.names'))
            ->view('externaldatum::xplore.index', true)
            ->data(compact('xplores', 'view'))
            ->output();
    }

    /**
     * Display xplore.
     *
     * @param Request $request
     * @param Model   $xplore
     *
     * @return Response
     */
    public function show(XploreRequest $request, Xplore $xplore)
    {

        if ($xplore->exists) {
            $view = 'externaldatum::xplore.show';
        } else {
            $view = 'externaldatum::xplore.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('externaldatum::xplore.name'))
            ->data(compact('xplore'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new xplore.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(XploreRequest $request)
    {

        $xplore = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('externaldatum::xplore.name')) 
            ->view('externaldatum::xplore.create', true) 
            ->data(compact('xplore'))
            ->output();
    }

    /**
     * Create new xplore.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(XploreRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $xplore                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('externaldatum::xplore.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('externaldatum/xplore/' . $xplore->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/externaldatum/xplore'))
                ->redirect();
        }

    }

    /**
     * Show xplore for editing.
     *
     * @param Request $request
     * @param Model   $xplore
     *
     * @return Response
     */
    public function edit(XploreRequest $request, Xplore $xplore)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('externaldatum::xplore.name'))
            ->view('externaldatum::xplore.edit', true)
            ->data(compact('xplore'))
            ->output();
    }

    /**
     * Update the xplore.
     *
     * @param Request $request
     * @param Model   $xplore
     *
     * @return Response
     */
    public function update(XploreRequest $request, Xplore $xplore)
    {
        try {
            $attributes = $request->all();

            $xplore->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('externaldatum::xplore.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('externaldatum/xplore/' . $xplore->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('externaldatum/xplore/' . $xplore->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the xplore.
     *
     * @param Model   $xplore
     *
     * @return Response
     */
    public function destroy(XploreRequest $request, Xplore $xplore)
    {
        try {

            $xplore->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('externaldatum::xplore.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('externaldatum/xplore/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('externaldatum/xplore/' . $xplore->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple xplore.
     *
     * @param Model   $xplore
     *
     * @return Response
     */
    public function delete(XploreRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('externaldatum::xplore.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('externaldatum/xplore'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/externaldatum/xplore'))
                ->redirect();
        }

    }

    /**
     * Restore deleted xplores.
     *
     * @param Model   $xplore
     *
     * @return Response
     */
    public function restore(XploreRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('externaldatum::xplore.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/externaldatum/xplore'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/externaldatum/xplore/'))
                ->redirect();
        }

    }

}
